## 0.1.2
**Added**
* Added minimal Token based authentication
* Added Some exception handler class for exception handling
* Added model and migrations for AuthToken model

## 0.1.3
**Fixed**
* django auth app user is not responding in graphql api
